quantizationtools.ConcatenatingGraceHandler
===========================================

.. abjad-lineage:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler

.. autoclass:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.grace_duration
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__call__
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__eq__
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__format__
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__hash__
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__ne__
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__repr__

Bases
-----

- :py:class:`quantizationtools.GraceHandler <abjad.tools.quantizationtools.GraceHandler.GraceHandler>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.grace_duration
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler.__repr__
   :noindex:
